"""This module contains the general information for EquipmentSwitchCap ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentSwitchCapConsts:
    DYNAMIC_VIFS_SUPPORTED_FALSE = "false"
    DYNAMIC_VIFS_SUPPORTED_NO = "no"
    DYNAMIC_VIFS_SUPPORTED_TRUE = "true"
    DYNAMIC_VIFS_SUPPORTED_YES = "yes"
    FAN_MODULES_SUPPORTED_FALSE = "false"
    FAN_MODULES_SUPPORTED_NO = "no"
    FAN_MODULES_SUPPORTED_TRUE = "true"
    FAN_MODULES_SUPPORTED_YES = "yes"
    INT_ID_NONE = "none"
    LOCATOR_BEACON_SUPPORTED_FALSE = "false"
    LOCATOR_BEACON_SUPPORTED_NO = "no"
    LOCATOR_BEACON_SUPPORTED_TRUE = "true"
    LOCATOR_BEACON_SUPPORTED_YES = "yes"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    SERENO_NETFLOW_SUPPORTED_FALSE = "false"
    SERENO_NETFLOW_SUPPORTED_NO = "no"
    SERENO_NETFLOW_SUPPORTED_TRUE = "true"
    SERENO_NETFLOW_SUPPORTED_YES = "yes"
    VP_COMPRESSION_SUPPORTED_FALSE = "false"
    VP_COMPRESSION_SUPPORTED_NO = "no"
    VP_COMPRESSION_SUPPORTED_TRUE = "true"
    VP_COMPRESSION_SUPPORTED_YES = "yes"


class EquipmentSwitchCap(ManagedObject):
    """This is EquipmentSwitchCap class."""

    consts = EquipmentSwitchCapConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentSwitchCap", "equipmentSwitchCap", "switch-cap", VersionMeta.Version111j, "InputOutput", 0xff, [], [""], ['equipmentSwitchCapProvider', 'equipmentSwitchIOCardCapProvider'], ['equipmentPortCap'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "dynamic_vifs_supported": MoPropertyMeta("dynamic_vifs_supported", "dynamicVifsSupported", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "fan_modules_supported": MoPropertyMeta("fan_modules_supported", "fanModulesSupported", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "locator_beacon_supported": MoPropertyMeta("locator_beacon_supported", "locatorBeaconSupported", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "max_active_span_session_count": MoPropertyMeta("max_active_span_session_count", "maxActiveSpanSessionCount", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "max_eth1g_port": MoPropertyMeta("max_eth1g_port", "maxEth1gPort", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "max_eth1g_slot": MoPropertyMeta("max_eth1g_slot", "maxEth1gSlot", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "max_eth_pc_members": MoPropertyMeta("max_eth_pc_members", "maxEthPcMembers", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "max_eth_pcs": MoPropertyMeta("max_eth_pcs", "maxEthPcs", "uint", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "max_fc_pcs": MoPropertyMeta("max_fc_pcs", "maxFcPcs", "uint", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "max_fcoe_pc_members": MoPropertyMeta("max_fcoe_pc_members", "maxFcoePcMembers", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "max_port_id": MoPropertyMeta("max_port_id", "maxPortId", "uint", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "max_slot": MoPropertyMeta("max_slot", "maxSlot", "uint", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "max_uplink_ports": MoPropertyMeta("max_uplink_ports", "maxUplinkPorts", "uint", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mgmt_daughter_card_slot_id": MoPropertyMeta("mgmt_daughter_card_slot_id", "mgmtDaughterCardSlotId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "min_active_fan": MoPropertyMeta("min_active_fan", "minActiveFan", "ushort", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-65535"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "sereno_netflow_supported": MoPropertyMeta("sereno_netflow_supported", "serenoNetflowSupported", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "vp_compression_supported": MoPropertyMeta("vp_compression_supported", "vpCompressionSupported", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "dynamicVifsSupported": "dynamic_vifs_supported", 
        "fanModulesSupported": "fan_modules_supported", 
        "intId": "int_id", 
        "locatorBeaconSupported": "locator_beacon_supported", 
        "maxActiveSpanSessionCount": "max_active_span_session_count", 
        "maxEth1gPort": "max_eth1g_port", 
        "maxEth1gSlot": "max_eth1g_slot", 
        "maxEthPcMembers": "max_eth_pc_members", 
        "maxEthPcs": "max_eth_pcs", 
        "maxFcPcs": "max_fc_pcs", 
        "maxFcoePcMembers": "max_fcoe_pc_members", 
        "maxPortId": "max_port_id", 
        "maxSlot": "max_slot", 
        "maxUplinkPorts": "max_uplink_ports", 
        "mgmtDaughterCardSlotId": "mgmt_daughter_card_slot_id", 
        "minActiveFan": "min_active_fan", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serenoNetflowSupported": "sereno_netflow_supported", 
        "status": "status", 
        "vpCompressionSupported": "vp_compression_supported", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.descr = None
        self.dynamic_vifs_supported = None
        self.fan_modules_supported = None
        self.int_id = None
        self.locator_beacon_supported = None
        self.max_active_span_session_count = None
        self.max_eth1g_port = None
        self.max_eth1g_slot = None
        self.max_eth_pc_members = None
        self.max_eth_pcs = None
        self.max_fc_pcs = None
        self.max_fcoe_pc_members = None
        self.max_port_id = None
        self.max_slot = None
        self.max_uplink_ports = None
        self.mgmt_daughter_card_slot_id = None
        self.min_active_fan = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.sereno_netflow_supported = None
        self.status = None
        self.vp_compression_supported = None

        ManagedObject.__init__(self, "EquipmentSwitchCap", parent_mo_or_dn, **kwargs)



"""This module contains the general information for LsServerExtension ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LsServerExtensionConsts:
    pass


class LsServerExtension(ManagedObject):
    """This is LsServerExtension class."""

    consts = LsServerExtensionConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsServerExtension", "lsServerExtension", "extension", VersionMeta.Version212a, "InputOutput", 0x7f, [], ["admin", "ls-compute", "ls-config", "ls-server"], ['lsServer'], [], ["Get", "Set"])

    prop_meta = {
        "asset_tag": MoPropertyMeta("asset_tag", "assetTag", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x10, 0, 510, None, [], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "version": MoPropertyMeta("version", "version", "uint", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "vlan_grp_request_compute_time": MoPropertyMeta("vlan_grp_request_compute_time", "vlanGrpRequestComputeTime", "string", VersionMeta.Version226c, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
    }

    prop_map = {
        "assetTag": "asset_tag", 
        "childAction": "child_action", 
        "dn": "dn", 
        "guid": "guid", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "version": "version", 
        "vlanGrpRequestComputeTime": "vlan_grp_request_compute_time", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.asset_tag = None
        self.child_action = None
        self.guid = None
        self.prop_acl = None
        self.sacl = None
        self.status = None
        self.version = None
        self.vlan_grp_request_compute_time = None

        ManagedObject.__init__(self, "LsServerExtension", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputeChassisQual ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeChassisQualConsts:
    pass


class ComputeChassisQual(ManagedObject):
    """This is ComputeChassisQual class."""

    consts = ComputeChassisQualConsts()
    naming_props = set(['minId', 'maxId'])

    mo_meta = MoMeta("ComputeChassisQual", "computeChassisQual", "chassis-from-[min_id]-to-[max_id]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["admin", "pn-policy"], ['computeQual'], ['computeSlotQual'], ["Add", "Get", "Remove"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "max_id": MoPropertyMeta("max_id", "maxId", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x8, None, None, None, [], ["1-255"]),
        "min_id": MoPropertyMeta("min_id", "minId", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x10, None, None, None, [], ["1-255"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "maxId": "max_id", 
        "minId": "min_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, min_id, max_id, **kwargs):
        self._dirty_mask = 0
        self.min_id = min_id
        self.max_id = max_id
        self.child_action = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ComputeChassisQual", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwCmclan ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwCmclanConsts:
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"


class SwCmclan(ManagedObject):
    """This is SwCmclan class."""

    consts = SwCmclanConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("SwCmclan", "swCmclan", "vlan-cmc[id]", VersionMeta.Version221b, "InputOutput", 0x7f, [], ["read-only"], ['dcxVc'], ['fabricNetGroupRef'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cimc_ids": MoPropertyMeta("cimc_ids", "cimcIds", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""(defaultValue){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version221b, MoPropertyMeta.NAMING, 0x8, None, None, None, [], ["1-4093"]),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "cimcIds": "cimc_ids", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "id": "id", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "locale": "locale", 
        "name": "name", 
        "peerDn": "peer_dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.cimc_ids = None
        self.ep_dn = None
        self.if_role = None
        self.if_type = None
        self.locale = None
        self.name = None
        self.peer_dn = None
        self.sacl = None
        self.status = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "SwCmclan", parent_mo_or_dn, **kwargs)



# Copyright 2017 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose import SkipTest
from nose.tools import with_setup, assert_equal
import threading
from ..connection.info import custom_setup, custom_teardown, get_skip_msg

handle = None


def setup_module():
    global handle
    handle = custom_setup()
    if not handle:
        msg = get_skip_msg()
        raise SkipTest(msg)


def teardown_module():
    custom_teardown(handle)


def t1_func():
    from ucsmsdk.mometa.ls.LsServer import LsServer
    obj = LsServer("org-root", "temp_sp1")
    handle.add_mo(obj)


def t2_func():
    from ucsmsdk.mometa.ls.LsServer import LsServer
    obj1 = LsServer("org-root", "temp_sp2")
    obj2 = LsServer("org-root", "temp_sp3")
    handle.add_mo(obj1)
    handle.add_mo(obj2)


@with_setup(setup_module, teardown_module)
def test_test_threading_mode():
    handle.set_mode_threading()

    t1 = threading.Thread(name="t1", target=t1_func)
    t2 = threading.Thread(name="t2", target=t2_func)

    t1.start()
    t2.start()

    t1.join()
    t2.join()

    # commit buffers should be in different contexts
    buf1 = handle._get_commit_buf(tag="t1")
    buf2 = handle._get_commit_buf(tag="t2")

    assert_equal(len(buf1), 1)
    assert_equal(len(buf2), 2)

    handle.commit_buffer_discard(tag="t1")
    handle.commit_buffer_discard(tag="t2")

    handle.unset_mode_threading()



"""This module contains the meta information of ApeGetMcStats ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeGetMcStats", "apeGetMcStats", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_equipment_serial": MethodPropertyMeta("InEquipmentSerial", "inEquipmentSerial", "Xs:string", "Version142b", "Input", False),
    "out_mc_stats": MethodPropertyMeta("OutMcStats", "outMcStats", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inEquipmentSerial": "in_equipment_serial",
    "outMcStats": "out_mc_stats",
}



"""This module contains the general information for ProcessorExecStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorExecStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorExecStats(ManagedObject):
    """This is ProcessorExecStats class."""

    consts = ProcessorExecStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorExecStats", "processorExecStats", "exec-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "decode_unit_correctable_errors": MoPropertyMeta("decode_unit_correctable_errors", "DecodeUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors15_min": MoPropertyMeta("decode_unit_correctable_errors15_min", "DecodeUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors15_min_h": MoPropertyMeta("decode_unit_correctable_errors15_min_h", "DecodeUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_day": MoPropertyMeta("decode_unit_correctable_errors1_day", "DecodeUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_day_h": MoPropertyMeta("decode_unit_correctable_errors1_day_h", "DecodeUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_hour": MoPropertyMeta("decode_unit_correctable_errors1_hour", "DecodeUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_hour_h": MoPropertyMeta("decode_unit_correctable_errors1_hour_h", "DecodeUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_week": MoPropertyMeta("decode_unit_correctable_errors1_week", "DecodeUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors1_week_h": MoPropertyMeta("decode_unit_correctable_errors1_week_h", "DecodeUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors2_weeks": MoPropertyMeta("decode_unit_correctable_errors2_weeks", "DecodeUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_correctable_errors2_weeks_h": MoPropertyMeta("decode_unit_correctable_errors2_weeks_h", "DecodeUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors": MoPropertyMeta("decode_unit_uncorrectable_errors", "DecodeUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors15_min": MoPropertyMeta("decode_unit_uncorrectable_errors15_min", "DecodeUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors15_min_h": MoPropertyMeta("decode_unit_uncorrectable_errors15_min_h", "DecodeUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_day": MoPropertyMeta("decode_unit_uncorrectable_errors1_day", "DecodeUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_day_h": MoPropertyMeta("decode_unit_uncorrectable_errors1_day_h", "DecodeUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_hour": MoPropertyMeta("decode_unit_uncorrectable_errors1_hour", "DecodeUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("decode_unit_uncorrectable_errors1_hour_h", "DecodeUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_week": MoPropertyMeta("decode_unit_uncorrectable_errors1_week", "DecodeUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors1_week_h": MoPropertyMeta("decode_unit_uncorrectable_errors1_week_h", "DecodeUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors2_weeks": MoPropertyMeta("decode_unit_uncorrectable_errors2_weeks", "DecodeUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "decode_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("decode_unit_uncorrectable_errors2_weeks_h", "DecodeUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors": MoPropertyMeta("execution_unit_correctable_errors", "ExecutionUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors15_min": MoPropertyMeta("execution_unit_correctable_errors15_min", "ExecutionUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors15_min_h": MoPropertyMeta("execution_unit_correctable_errors15_min_h", "ExecutionUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_day": MoPropertyMeta("execution_unit_correctable_errors1_day", "ExecutionUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_day_h": MoPropertyMeta("execution_unit_correctable_errors1_day_h", "ExecutionUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_hour": MoPropertyMeta("execution_unit_correctable_errors1_hour", "ExecutionUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_hour_h": MoPropertyMeta("execution_unit_correctable_errors1_hour_h", "ExecutionUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_week": MoPropertyMeta("execution_unit_correctable_errors1_week", "ExecutionUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors1_week_h": MoPropertyMeta("execution_unit_correctable_errors1_week_h", "ExecutionUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors2_weeks": MoPropertyMeta("execution_unit_correctable_errors2_weeks", "ExecutionUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_correctable_errors2_weeks_h": MoPropertyMeta("execution_unit_correctable_errors2_weeks_h", "ExecutionUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors": MoPropertyMeta("execution_unit_uncorrectable_errors", "ExecutionUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors15_min": MoPropertyMeta("execution_unit_uncorrectable_errors15_min", "ExecutionUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors15_min_h": MoPropertyMeta("execution_unit_uncorrectable_errors15_min_h", "ExecutionUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_day": MoPropertyMeta("execution_unit_uncorrectable_errors1_day", "ExecutionUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_day_h": MoPropertyMeta("execution_unit_uncorrectable_errors1_day_h", "ExecutionUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_hour": MoPropertyMeta("execution_unit_uncorrectable_errors1_hour", "ExecutionUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("execution_unit_uncorrectable_errors1_hour_h", "ExecutionUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_week": MoPropertyMeta("execution_unit_uncorrectable_errors1_week", "ExecutionUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors1_week_h": MoPropertyMeta("execution_unit_uncorrectable_errors1_week_h", "ExecutionUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors2_weeks": MoPropertyMeta("execution_unit_uncorrectable_errors2_weeks", "ExecutionUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "execution_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("execution_unit_uncorrectable_errors2_weeks_h", "ExecutionUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors": MoPropertyMeta("instruction_fetch_unit_correctable_errors", "InstructionFetchUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors15_min": MoPropertyMeta("instruction_fetch_unit_correctable_errors15_min", "InstructionFetchUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors15_min_h": MoPropertyMeta("instruction_fetch_unit_correctable_errors15_min_h", "InstructionFetchUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_day": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_day", "InstructionFetchUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_day_h": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_day_h", "InstructionFetchUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_hour": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_hour", "InstructionFetchUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_hour_h": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_hour_h", "InstructionFetchUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_week": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_week", "InstructionFetchUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors1_week_h": MoPropertyMeta("instruction_fetch_unit_correctable_errors1_week_h", "InstructionFetchUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors2_weeks": MoPropertyMeta("instruction_fetch_unit_correctable_errors2_weeks", "InstructionFetchUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_correctable_errors2_weeks_h": MoPropertyMeta("instruction_fetch_unit_correctable_errors2_weeks_h", "InstructionFetchUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors", "InstructionFetchUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors15_min": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors15_min", "InstructionFetchUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors15_min_h": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors15_min_h", "InstructionFetchUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_day": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_day", "InstructionFetchUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_day_h": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_day_h", "InstructionFetchUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_hour": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_hour", "InstructionFetchUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_hour_h", "InstructionFetchUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_week": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_week", "InstructionFetchUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors1_week_h": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors1_week_h", "InstructionFetchUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors2_weeks": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors2_weeks", "InstructionFetchUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "instruction_fetch_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("instruction_fetch_unit_uncorrectable_errors2_weeks_h", "InstructionFetchUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors": MoPropertyMeta("load_store_unit_correctable_errors", "LoadStoreUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors15_min": MoPropertyMeta("load_store_unit_correctable_errors15_min", "LoadStoreUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors15_min_h": MoPropertyMeta("load_store_unit_correctable_errors15_min_h", "LoadStoreUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_day": MoPropertyMeta("load_store_unit_correctable_errors1_day", "LoadStoreUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_day_h": MoPropertyMeta("load_store_unit_correctable_errors1_day_h", "LoadStoreUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_hour": MoPropertyMeta("load_store_unit_correctable_errors1_hour", "LoadStoreUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_hour_h": MoPropertyMeta("load_store_unit_correctable_errors1_hour_h", "LoadStoreUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_week": MoPropertyMeta("load_store_unit_correctable_errors1_week", "LoadStoreUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors1_week_h": MoPropertyMeta("load_store_unit_correctable_errors1_week_h", "LoadStoreUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors2_weeks": MoPropertyMeta("load_store_unit_correctable_errors2_weeks", "LoadStoreUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_correctable_errors2_weeks_h": MoPropertyMeta("load_store_unit_correctable_errors2_weeks_h", "LoadStoreUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors": MoPropertyMeta("load_store_unit_uncorrectable_errors", "LoadStoreUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors15_min": MoPropertyMeta("load_store_unit_uncorrectable_errors15_min", "LoadStoreUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors15_min_h": MoPropertyMeta("load_store_unit_uncorrectable_errors15_min_h", "LoadStoreUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_day": MoPropertyMeta("load_store_unit_uncorrectable_errors1_day", "LoadStoreUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_day_h": MoPropertyMeta("load_store_unit_uncorrectable_errors1_day_h", "LoadStoreUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_hour": MoPropertyMeta("load_store_unit_uncorrectable_errors1_hour", "LoadStoreUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("load_store_unit_uncorrectable_errors1_hour_h", "LoadStoreUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_week": MoPropertyMeta("load_store_unit_uncorrectable_errors1_week", "LoadStoreUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors1_week_h": MoPropertyMeta("load_store_unit_uncorrectable_errors1_week_h", "LoadStoreUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors2_weeks": MoPropertyMeta("load_store_unit_uncorrectable_errors2_weeks", "LoadStoreUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "load_store_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("load_store_unit_uncorrectable_errors2_weeks_h", "LoadStoreUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "DecodeUnitCorrectableErrors": "decode_unit_correctable_errors", 
        "DecodeUnitCorrectableErrors15Min": "decode_unit_correctable_errors15_min", 
        "DecodeUnitCorrectableErrors15MinH": "decode_unit_correctable_errors15_min_h", 
        "DecodeUnitCorrectableErrors1Day": "decode_unit_correctable_errors1_day", 
        "DecodeUnitCorrectableErrors1DayH": "decode_unit_correctable_errors1_day_h", 
        "DecodeUnitCorrectableErrors1Hour": "decode_unit_correctable_errors1_hour", 
        "DecodeUnitCorrectableErrors1HourH": "decode_unit_correctable_errors1_hour_h", 
        "DecodeUnitCorrectableErrors1Week": "decode_unit_correctable_errors1_week", 
        "DecodeUnitCorrectableErrors1WeekH": "decode_unit_correctable_errors1_week_h", 
        "DecodeUnitCorrectableErrors2Weeks": "decode_unit_correctable_errors2_weeks", 
        "DecodeUnitCorrectableErrors2WeeksH": "decode_unit_correctable_errors2_weeks_h", 
        "DecodeUnitUncorrectableErrors": "decode_unit_uncorrectable_errors", 
        "DecodeUnitUncorrectableErrors15Min": "decode_unit_uncorrectable_errors15_min", 
        "DecodeUnitUncorrectableErrors15MinH": "decode_unit_uncorrectable_errors15_min_h", 
        "DecodeUnitUncorrectableErrors1Day": "decode_unit_uncorrectable_errors1_day", 
        "DecodeUnitUncorrectableErrors1DayH": "decode_unit_uncorrectable_errors1_day_h", 
        "DecodeUnitUncorrectableErrors1Hour": "decode_unit_uncorrectable_errors1_hour", 
        "DecodeUnitUncorrectableErrors1HourH": "decode_unit_uncorrectable_errors1_hour_h", 
        "DecodeUnitUncorrectableErrors1Week": "decode_unit_uncorrectable_errors1_week", 
        "DecodeUnitUncorrectableErrors1WeekH": "decode_unit_uncorrectable_errors1_week_h", 
        "DecodeUnitUncorrectableErrors2Weeks": "decode_unit_uncorrectable_errors2_weeks", 
        "DecodeUnitUncorrectableErrors2WeeksH": "decode_unit_uncorrectable_errors2_weeks_h", 
        "ExecutionUnitCorrectableErrors": "execution_unit_correctable_errors", 
        "ExecutionUnitCorrectableErrors15Min": "execution_unit_correctable_errors15_min", 
        "ExecutionUnitCorrectableErrors15MinH": "execution_unit_correctable_errors15_min_h", 
        "ExecutionUnitCorrectableErrors1Day": "execution_unit_correctable_errors1_day", 
        "ExecutionUnitCorrectableErrors1DayH": "execution_unit_correctable_errors1_day_h", 
        "ExecutionUnitCorrectableErrors1Hour": "execution_unit_correctable_errors1_hour", 
        "ExecutionUnitCorrectableErrors1HourH": "execution_unit_correctable_errors1_hour_h", 
        "ExecutionUnitCorrectableErrors1Week": "execution_unit_correctable_errors1_week", 
        "ExecutionUnitCorrectableErrors1WeekH": "execution_unit_correctable_errors1_week_h", 
        "ExecutionUnitCorrectableErrors2Weeks": "execution_unit_correctable_errors2_weeks", 
        "ExecutionUnitCorrectableErrors2WeeksH": "execution_unit_correctable_errors2_weeks_h", 
        "ExecutionUnitUncorrectableErrors": "execution_unit_uncorrectable_errors", 
        "ExecutionUnitUncorrectableErrors15Min": "execution_unit_uncorrectable_errors15_min", 
        "ExecutionUnitUncorrectableErrors15MinH": "execution_unit_uncorrectable_errors15_min_h", 
        "ExecutionUnitUncorrectableErrors1Day": "execution_unit_uncorrectable_errors1_day", 
        "ExecutionUnitUncorrectableErrors1DayH": "execution_unit_uncorrectable_errors1_day_h", 
        "ExecutionUnitUncorrectableErrors1Hour": "execution_unit_uncorrectable_errors1_hour", 
        "ExecutionUnitUncorrectableErrors1HourH": "execution_unit_uncorrectable_errors1_hour_h", 
        "ExecutionUnitUncorrectableErrors1Week": "execution_unit_uncorrectable_errors1_week", 
        "ExecutionUnitUncorrectableErrors1WeekH": "execution_unit_uncorrectable_errors1_week_h", 
        "ExecutionUnitUncorrectableErrors2Weeks": "execution_unit_uncorrectable_errors2_weeks", 
        "ExecutionUnitUncorrectableErrors2WeeksH": "execution_unit_uncorrectable_errors2_weeks_h", 
        "InstructionFetchUnitCorrectableErrors": "instruction_fetch_unit_correctable_errors", 
        "InstructionFetchUnitCorrectableErrors15Min": "instruction_fetch_unit_correctable_errors15_min", 
        "InstructionFetchUnitCorrectableErrors15MinH": "instruction_fetch_unit_correctable_errors15_min_h", 
        "InstructionFetchUnitCorrectableErrors1Day": "instruction_fetch_unit_correctable_errors1_day", 
        "InstructionFetchUnitCorrectableErrors1DayH": "instruction_fetch_unit_correctable_errors1_day_h", 
        "InstructionFetchUnitCorrectableErrors1Hour": "instruction_fetch_unit_correctable_errors1_hour", 
        "InstructionFetchUnitCorrectableErrors1HourH": "instruction_fetch_unit_correctable_errors1_hour_h", 
        "InstructionFetchUnitCorrectableErrors1Week": "instruction_fetch_unit_correctable_errors1_week", 
        "InstructionFetchUnitCorrectableErrors1WeekH": "instruction_fetch_unit_correctable_errors1_week_h", 
        "InstructionFetchUnitCorrectableErrors2Weeks": "instruction_fetch_unit_correctable_errors2_weeks", 
        "InstructionFetchUnitCorrectableErrors2WeeksH": "instruction_fetch_unit_correctable_errors2_weeks_h", 
        "InstructionFetchUnitUncorrectableErrors": "instruction_fetch_unit_uncorrectable_errors", 
        "InstructionFetchUnitUncorrectableErrors15Min": "instruction_fetch_unit_uncorrectable_errors15_min", 
        "InstructionFetchUnitUncorrectableErrors15MinH": "instruction_fetch_unit_uncorrectable_errors15_min_h", 
        "InstructionFetchUnitUncorrectableErrors1Day": "instruction_fetch_unit_uncorrectable_errors1_day", 
        "InstructionFetchUnitUncorrectableErrors1DayH": "instruction_fetch_unit_uncorrectable_errors1_day_h", 
        "InstructionFetchUnitUncorrectableErrors1Hour": "instruction_fetch_unit_uncorrectable_errors1_hour", 
        "InstructionFetchUnitUncorrectableErrors1HourH": "instruction_fetch_unit_uncorrectable_errors1_hour_h", 
        "InstructionFetchUnitUncorrectableErrors1Week": "instruction_fetch_unit_uncorrectable_errors1_week", 
        "InstructionFetchUnitUncorrectableErrors1WeekH": "instruction_fetch_unit_uncorrectable_errors1_week_h", 
        "InstructionFetchUnitUncorrectableErrors2Weeks": "instruction_fetch_unit_uncorrectable_errors2_weeks", 
        "InstructionFetchUnitUncorrectableErrors2WeeksH": "instruction_fetch_unit_uncorrectable_errors2_weeks_h", 
        "LoadStoreUnitCorrectableErrors": "load_store_unit_correctable_errors", 
        "LoadStoreUnitCorrectableErrors15Min": "load_store_unit_correctable_errors15_min", 
        "LoadStoreUnitCorrectableErrors15MinH": "load_store_unit_correctable_errors15_min_h", 
        "LoadStoreUnitCorrectableErrors1Day": "load_store_unit_correctable_errors1_day", 
        "LoadStoreUnitCorrectableErrors1DayH": "load_store_unit_correctable_errors1_day_h", 
        "LoadStoreUnitCorrectableErrors1Hour": "load_store_unit_correctable_errors1_hour", 
        "LoadStoreUnitCorrectableErrors1HourH": "load_store_unit_correctable_errors1_hour_h", 
        "LoadStoreUnitCorrectableErrors1Week": "load_store_unit_correctable_errors1_week", 
        "LoadStoreUnitCorrectableErrors1WeekH": "load_store_unit_correctable_errors1_week_h", 
        "LoadStoreUnitCorrectableErrors2Weeks": "load_store_unit_correctable_errors2_weeks", 
        "LoadStoreUnitCorrectableErrors2WeeksH": "load_store_unit_correctable_errors2_weeks_h", 
        "LoadStoreUnitUncorrectableErrors": "load_store_unit_uncorrectable_errors", 
        "LoadStoreUnitUncorrectableErrors15Min": "load_store_unit_uncorrectable_errors15_min", 
        "LoadStoreUnitUncorrectableErrors15MinH": "load_store_unit_uncorrectable_errors15_min_h", 
        "LoadStoreUnitUncorrectableErrors1Day": "load_store_unit_uncorrectable_errors1_day", 
        "LoadStoreUnitUncorrectableErrors1DayH": "load_store_unit_uncorrectable_errors1_day_h", 
        "LoadStoreUnitUncorrectableErrors1Hour": "load_store_unit_uncorrectable_errors1_hour", 
        "LoadStoreUnitUncorrectableErrors1HourH": "load_store_unit_uncorrectable_errors1_hour_h", 
        "LoadStoreUnitUncorrectableErrors1Week": "load_store_unit_uncorrectable_errors1_week", 
        "LoadStoreUnitUncorrectableErrors1WeekH": "load_store_unit_uncorrectable_errors1_week_h", 
        "LoadStoreUnitUncorrectableErrors2Weeks": "load_store_unit_uncorrectable_errors2_weeks", 
        "LoadStoreUnitUncorrectableErrors2WeeksH": "load_store_unit_uncorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.decode_unit_correctable_errors = None
        self.decode_unit_correctable_errors15_min = None
        self.decode_unit_correctable_errors15_min_h = None
        self.decode_unit_correctable_errors1_day = None
        self.decode_unit_correctable_errors1_day_h = None
        self.decode_unit_correctable_errors1_hour = None
        self.decode_unit_correctable_errors1_hour_h = None
        self.decode_unit_correctable_errors1_week = None
        self.decode_unit_correctable_errors1_week_h = None
        self.decode_unit_correctable_errors2_weeks = None
        self.decode_unit_correctable_errors2_weeks_h = None
        self.decode_unit_uncorrectable_errors = None
        self.decode_unit_uncorrectable_errors15_min = None
        self.decode_unit_uncorrectable_errors15_min_h = None
        self.decode_unit_uncorrectable_errors1_day = None
        self.decode_unit_uncorrectable_errors1_day_h = None
        self.decode_unit_uncorrectable_errors1_hour = None
        self.decode_unit_uncorrectable_errors1_hour_h = None
        self.decode_unit_uncorrectable_errors1_week = None
        self.decode_unit_uncorrectable_errors1_week_h = None
        self.decode_unit_uncorrectable_errors2_weeks = None
        self.decode_unit_uncorrectable_errors2_weeks_h = None
        self.execution_unit_correctable_errors = None
        self.execution_unit_correctable_errors15_min = None
        self.execution_unit_correctable_errors15_min_h = None
        self.execution_unit_correctable_errors1_day = None
        self.execution_unit_correctable_errors1_day_h = None
        self.execution_unit_correctable_errors1_hour = None
        self.execution_unit_correctable_errors1_hour_h = None
        self.execution_unit_correctable_errors1_week = None
        self.execution_unit_correctable_errors1_week_h = None
        self.execution_unit_correctable_errors2_weeks = None
        self.execution_unit_correctable_errors2_weeks_h = None
        self.execution_unit_uncorrectable_errors = None
        self.execution_unit_uncorrectable_errors15_min = None
        self.execution_unit_uncorrectable_errors15_min_h = None
        self.execution_unit_uncorrectable_errors1_day = None
        self.execution_unit_uncorrectable_errors1_day_h = None
        self.execution_unit_uncorrectable_errors1_hour = None
        self.execution_unit_uncorrectable_errors1_hour_h = None
        self.execution_unit_uncorrectable_errors1_week = None
        self.execution_unit_uncorrectable_errors1_week_h = None
        self.execution_unit_uncorrectable_errors2_weeks = None
        self.execution_unit_uncorrectable_errors2_weeks_h = None
        self.instruction_fetch_unit_correctable_errors = None
        self.instruction_fetch_unit_correctable_errors15_min = None
        self.instruction_fetch_unit_correctable_errors15_min_h = None
        self.instruction_fetch_unit_correctable_errors1_day = None
        self.instruction_fetch_unit_correctable_errors1_day_h = None
        self.instruction_fetch_unit_correctable_errors1_hour = None
        self.instruction_fetch_unit_correctable_errors1_hour_h = None
        self.instruction_fetch_unit_correctable_errors1_week = None
        self.instruction_fetch_unit_correctable_errors1_week_h = None
        self.instruction_fetch_unit_correctable_errors2_weeks = None
        self.instruction_fetch_unit_correctable_errors2_weeks_h = None
        self.instruction_fetch_unit_uncorrectable_errors = None
        self.instruction_fetch_unit_uncorrectable_errors15_min = None
        self.instruction_fetch_unit_uncorrectable_errors15_min_h = None
        self.instruction_fetch_unit_uncorrectable_errors1_day = None
        self.instruction_fetch_unit_uncorrectable_errors1_day_h = None
        self.instruction_fetch_unit_uncorrectable_errors1_hour = None
        self.instruction_fetch_unit_uncorrectable_errors1_hour_h = None
        self.instruction_fetch_unit_uncorrectable_errors1_week = None
        self.instruction_fetch_unit_uncorrectable_errors1_week_h = None
        self.instruction_fetch_unit_uncorrectable_errors2_weeks = None
        self.instruction_fetch_unit_uncorrectable_errors2_weeks_h = None
        self.load_store_unit_correctable_errors = None
        self.load_store_unit_correctable_errors15_min = None
        self.load_store_unit_correctable_errors15_min_h = None
        self.load_store_unit_correctable_errors1_day = None
        self.load_store_unit_correctable_errors1_day_h = None
        self.load_store_unit_correctable_errors1_hour = None
        self.load_store_unit_correctable_errors1_hour_h = None
        self.load_store_unit_correctable_errors1_week = None
        self.load_store_unit_correctable_errors1_week_h = None
        self.load_store_unit_correctable_errors2_weeks = None
        self.load_store_unit_correctable_errors2_weeks_h = None
        self.load_store_unit_uncorrectable_errors = None
        self.load_store_unit_uncorrectable_errors15_min = None
        self.load_store_unit_uncorrectable_errors15_min_h = None
        self.load_store_unit_uncorrectable_errors1_day = None
        self.load_store_unit_uncorrectable_errors1_day_h = None
        self.load_store_unit_uncorrectable_errors1_hour = None
        self.load_store_unit_uncorrectable_errors1_hour_h = None
        self.load_store_unit_uncorrectable_errors1_week = None
        self.load_store_unit_uncorrectable_errors1_week_h = None
        self.load_store_unit_uncorrectable_errors2_weeks = None
        self.load_store_unit_uncorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorExecStats", parent_mo_or_dn, **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup


with open('requirements.txt') as rf:
    requirements = rf.readlines()

with open('test-requirements.txt') as rf:
    test_requirements = rf.readlines()

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

setup(
    name='ucsmsdk',
    version='0.9.11',
    description="Python SDK for Cisco UCS",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/markdown',
    author="Cisco Systems Inc",
    author_email='ucs-python@cisco.com',
    url='https://github.com/CiscoUcs/ucsmsdk',
    packages=[
        'ucsmsdk',
    ],
    package_dir={'ucsmsdk':
                 'ucsmsdk'},
    include_package_data=True,
    install_requires=requirements,
    license="http://www.apache.org/licenses/LICENSE-2.0",
    zip_safe=False,
    keywords='ucsmsdk',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    tests_require=test_requirements,
    test_suite='nose.collector',
    extras_require={
        'ssl': ['pyOpenSSL'],
        'docs': ['sphinx<1.3', 'sphinxcontrib-napoleon', 'sphinx_rtd_theme'],
    }
)



# Copyright 2013 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module contains APIs used to launch the Java based UCSM GUI.
"""

from __future__ import print_function
from __future__ import unicode_literals

import os
import re
import subprocess
import logging

from .. import ucsgenutils
from ..ucsexception import UcsValidationException

log = logging.getLogger('ucs')


def ucs_gui_launch(handle, need_url=False):
    """
    ucs_gui_launch launches the Java based UCSM GUI.
    This method requires the necessary Jdk to be in place, for it to be
    successful.

    Args:
        handle (UcsHandle): Ucs connection handle
        need_url (bool): True/False,
                         returns the URL to launch GUI, if True

    Example:
        ucs_gui_launch(handle)\n
        ucs_gui_launch(handle, need_url=True)\n
    """

    import tempfile
    import fileinput
    import platform

    os_support = ["Windows", "Linux", "Microsoft", "Darwin"]
    if platform.system() not in os_support:
        raise UcsValidationException(
            "Unsupported operating system")

    jnlp_file = None
    try:
        ucsm_gui_url = "%s/ucsm/ucsm.jnlp" % handle.uri
        if handle:
            auth_token = handle.get_auth_token()
            log.debug("AuthToken: <%s>" % auth_token)
            if auth_token:
                ucsm_gui_url = "%s?ucsmToken=%s" % (ucsm_gui_url, auth_token)

        log.debug("UCSM URL: <%s>" % ucsm_gui_url)

        if need_url:
            return ucsm_gui_url
        else:
            javaws_path = ucsgenutils.get_java_installation_path()
            log.debug("javaws path: <%s>" % javaws_path)
            if javaws_path is not None:
                # source = urllib2.urlopen(ucsm_url).read()
                source = handle.post(uri=ucsm_gui_url)
                jnlp_dir = tempfile.gettempdir()
                log.debug("Temp Directory: <%s>" % jnlp_dir)
                jnlp_file = os.path.join(jnlp_dir, "temp.jnlp")
                if os.path.exists(jnlp_file):
                    os.remove(jnlp_file)

                jnlp_fh = open(jnlp_file, "wt+")
                jnlp_fh.write(source)
                jnlp_fh.close()

                java_str = ucsgenutils.get_java_version()
                log.debug("Java Version: <%s>" % java_str)

                # Adding both the property to enable the secure log in UCSM
                # independent of java versions.
                # if java version < 1.7_45, property to use is
                # "log.show.encrypted"
                # if java version >= 1.7_45, property to use is
                # "jnlp.ucsm.log.show.encrypted"

                debug_str_old_java = '\t<property ' \
                            'name="log.show.encrypted" ' \
                            'value="true"/>'

                debug_str_new_java = '\t<property ' \
                                'name="jnlp.ucsm.log.show.encrypted" ' \
                                'value="true"/>'

                for line in fileinput.input(jnlp_file, inplace=1):
                    if re.search(r'^\s*</resources>\s*$', line):
                        print(debug_str_old_java)
                        print(debug_str_new_java)
                    line = line.strip('\n') if line else line
                    print(line)
                subprocess.call([javaws_path, jnlp_file])
                if os.path.exists(jnlp_file):
                    os.remove(jnlp_file)
            else:
                return None
    except Exception as e:
        fileinput.close()
        if os.path.exists(jnlp_file):
            os.remove(jnlp_file)
        raise e



"""This module contains the general information for ComputeMemoryConfiguration ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeMemoryConfigurationConsts:
    ADMIN_MEMORY_STATE_POLICY = "policy"
    ADMIN_MEMORY_STATE_RESET_IN_PROGRESS = "reset-in-progress"
    ADMIN_MEMORY_STATE_RESET_MEMORY_ERRORS = "reset-memory-errors"
    BLACK_LISTING_DISABLED = "disabled"
    BLACK_LISTING_ENABLED = "enabled"


class ComputeMemoryConfiguration(ManagedObject):
    """This is ComputeMemoryConfiguration class."""

    consts = ComputeMemoryConfigurationConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeMemoryConfiguration", "computeMemoryConfiguration", "memmory-config", VersionMeta.Version221b, "InputOutput", 0x3f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['computeBlade', 'computeRackUnit', 'computeServerUnit'], [], ["Get", "Set"])

    prop_meta = {
        "admin_memory_state": MoPropertyMeta("admin_memory_state", "adminMemoryState", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["policy", "reset-in-progress", "reset-memory-errors"], []),
        "black_listing": MoPropertyMeta("black_listing", "blackListing", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "adminMemoryState": "admin_memory_state", 
        "blackListing": "black_listing", 
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_memory_state = None
        self.black_listing = None
        self.child_action = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ComputeMemoryConfiguration", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeUpdateApeFirmwareActiveSide ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeUpdateApeFirmwareActiveSide", "apeUpdateApeFirmwareActiveSide", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_field_name": MethodPropertyMeta("InFieldName", "inFieldName", "Xs:unsignedInt", "Version142b", "Input", False),
    "in_ip_addr": MethodPropertyMeta("InIpAddr", "inIpAddr", "AddressIPv4", "Version142b", "Input", False),
    "in_side": MethodPropertyMeta("InSide", "inSide", "Xs:unsignedInt", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inFieldName": "in_field_name",
    "inIpAddr": "in_ip_addr",
    "inSide": "in_side",
}



#!/usr/bin/python
# Copyright 2013 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module generated the python script using UCS GUI, GUI logs and xml
request.
"""

from __future__ import print_function

try:
    import xml.etree.cElementTree as ET
    from xml.etree.cElementTree import Element, SubElement
except ImportError:
    import cElementTree as ET
    from cElementTree import Element, SubElement


import os
import re
from ucsmsdk import ucsgenutils
from ucsmsdk import ucscoreutils

import logging

log = logging.getLogger('ucs')

classid_dn_map = {
    "OrgOrg": "org-root",
    "FabricEp": "fabric",
    "FaultHolder": "fault",
    "StatsHolder": "stats",
    "CallHomeEp": "call-home",
    "TopSystem": "sys"
}

import_list = []


def _generate_imports(imports):
    import_str = ""
    for each in imports:
        import_str += "from " + ucscoreutils.get_import_str(each) + " import " + each + "\n"
    import_str += "\n\n"
    return import_str


def _ignore_elem(elem):
    if elem.tag.startswith('aaa'):
        return True
    if elem.tag in ["biosVfUCSMBootOrderRuleControl",
                    "biosVfOptionROMLoad",
                    "policyControlEp",
                    "storageLocalDiskPartition"]:
        return True
    return False


class Node(object):

    def __init__(self, elem, tag,
                 parent_dn=None, parent_tag=None, parent_verb=None):
        self.elem = elem
        self.tag = tag
        self.parent_dn = parent_dn
        self.parent_tag = parent_tag
        self.parent_verb = parent_verb
        self.class_id = ucsgenutils.word_u(elem.tag)
        self.class_ref = ucscoreutils.load_class(self.class_id)
        self.mo_meta = self.class_ref.mo_meta
        self.prop_meta = self.class_ref.prop_meta
        self.prop_map = self.class_ref.prop_map
        self.dn = self._make_dn()
        self.verb = self._get_verb()
        self.child = []

    def _get_verb(self):
        verbs = self.mo_meta.verbs

        if "Add" in verbs:
            return "Add"
        elif "Set" in verbs:
            return "Set"
        else:
            return "Get"

    def _make_rn(self):
        rn_pattern = self.class_ref.mo_meta.rn
        prop_meta = self.class_ref.prop_meta

        for prop in re.findall(r"""\[([^\]]*)\]""", rn_pattern):
            prop_val = self.elem.attrib[prop_meta[prop].xml_attribute]
            rn_pattern = re.sub(r"""\[%s\]""" % prop, prop_val, rn_pattern)
        return rn_pattern

    def _make_dn(self):
        if self.parent_dn:
            return self.parent_dn + "/" + self._make_rn()
        return self._make_rn()

    def _create_prop_map(self, *args):
        property_map = {}
        for attribute in self.elem.attrib:
            if attribute not in self.prop_map:
                print(
                    "# attribute:" +
                    attribute +
                    " not recognised by this version of SDK. Ignoring..")
                continue
            prop_name_py = self.prop_map[attribute]
            prop_access = self.prop_meta[prop_name_py].access
            if prop_access in args:
                continue
            prop_val = self.elem.attrib[attribute]
            if prop_val != "":
                property_map[prop_name_py] = prop_val

        return property_map

    def _create_add_prop_map(self):
        return self._create_prop_map(2, 4)

    def _create_set_prop_map(self):
        return self._create_prop_map(0, 1, 2, 4)

    def _create_add_query(self):
        if self.class_id not in import_list:
            import_list.append(self.class_id)
        property_map = self._create_add_prop_map()
        property_map_str = ", ".join(
            [k + "=" + '"' + v + '"'
             for k, v in ucsgenutils.iteritems(property_map)])

        return "%s = %s(parent_mo_or_dn=%s, %s)\n" % (
            self.tag, self.class_id, self.parent_tag, property_map_str)

    def _create_set_query(self):
        if self.class_id not in import_list:
            import_list.append(self.class_id)

        if self.parent_verb not in ("Add", "Set"):
            query = '%s = handle.query_dn("%s")\n' % (self.tag, self.dn)
            property_map = self._create_set_prop_map()
            for prop in property_map:
                query += '%s.%s = "%s"\n' % (self.tag, prop,
                                             property_map[prop])
            return query
        else:
            return self._create_add_query()

    def _create_get_query(self):
        return '%s = handle.query_dn("%s")\n' % (self.tag, self.dn)

    def get_query(self):
        query = ""
        if self.verb == "Get":
            query = self._create_get_query()
        elif self.verb == "Add":
            query = self._create_add_query()

        elif self.verb == "Set":
            query = self._create_set_query()

        return query

    def process_query(self):
        query = ""
        query_ = self.get_query()
        if query_:
            query += query_
        for child in self.child:
            query += child.process_query()

        if self.parent_verb == "Get" and self.verb == "Add":
            query += "handle.add_mo(%s, True)\n" % self.tag
        if self.parent_verb == "Get" and self.verb == "Set":
            query += "handle.set_mo(%s)\n" % self.tag
        return query

    def __str__(self):
        query = self.process_query()
        if query:
            query += "handle.commit()\n"
        return query


def _process_child_elem(elem, tag, node, iter_count):
    call_count = iter_count
    for child in elem.getchildren():
        if _ignore_elem(child):
            continue

        child_tag = tag + '_' + str(call_count)
        child_node = Node(elem=child,
                          tag=child_tag,
                          parent_dn=node.dn,
                          parent_tag=node.tag,
                          parent_verb=node.verb)

        node.child.append(child_node)
        call_count += 1

        ret_obj = _process_child_elem(child, tag, child_node, call_count)
        call_count = ret_obj["iter_count"]

    return {"node": node, "iter_count": call_count}


def _generate_inner_nodes(elem, tag, parent_dn, parent_tag, parent_verb):

    class_id = ucsgenutils.word_u(elem.tag)
    if not ucscoreutils.is_valid_class_id(class_id):
        return

    node = Node(elem, tag, parent_dn, parent_tag, parent_verb)
    ret_obj = _process_child_elem(elem, tag, node, 1)

    return ret_obj["node"]


def _generate_outer_nodes(elem):

    top_nodes = []
    if elem.tag != "topRoot":
        return top_nodes

    for child in elem.getchildren():
        class_id = ucsgenutils.word_u(child.tag)
        if not ucscoreutils.is_valid_class_id(class_id) \
                or class_id not in classid_dn_map:
            continue

        parent_nodes = []
        for sub_child in child.getchildren():
            if _ignore_elem(sub_child):
                continue

            parent_node = Node(elem=child,
                               tag="obj",
                               parent_dn=None,
                               parent_tag=None,
                               parent_verb=None)
            parent_node.verb = "Get"
            parent_node.dn = classid_dn_map[class_id]

            child_node = _generate_inner_nodes(
                elem=sub_child,
                tag="mo",
                parent_dn=parent_node.dn,
                parent_tag=parent_node.tag,
                parent_verb=parent_node.verb)

            parent_node.child.append(child_node)
            parent_nodes.append(parent_node)
        top_nodes.append(parent_nodes)

    return top_nodes


def _generate_query(elem):

    query = ""
    top_nodes = _generate_outer_nodes(elem)
    for parent_nodes in top_nodes:
        query += "\n"
        for parent_node in parent_nodes:
            query += str(parent_node)
            query += "\n"
    return query


def convert_from_backup(backup_file, output_file=None):
    """
    converts UCS backup xml to a python script for the equivalent
    configuration.

    Args:
        backup_file (str): input file path for backup xml.
        output_file (str or None): file in which output is desired.
                                   None for stdout

    Example:
        convert_from_backup(backup_file="/home/user/backup.xml",
                            output_file="/home/user/output.py")

        convert_from_backup(backup_file="/home/user/backup.xml")

    """
    if not os.path.exists(backup_file):
        raise ValueError("%s does not exists." % backup_file)

    tree = ET.parse(backup_file)
    root = tree.getroot()

    script_output = _generate_query(root)
    imports_str = _generate_imports(import_list)
    boilerplate_start_str = """#!/usr/bin/env python

from ucsmsdk.ucshandle import UcsHandle

handle = UcsHandle(ip="", username="", password="")
handle.login()

"""

    boilerplate_end_str = """handle.logout()"""

    final_str = boilerplate_start_str + imports_str + script_output + boilerplate_end_str
    if output_file:
        _outfile = open(output_file, 'w')
        _outfile.write(final_str)
        _outfile.close()
    else:
        print(final_str)



"""This module contains the meta information of AaaCheckComputeExtAccess ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("AaaCheckComputeExtAccess", "aaaCheckComputeExtAccess", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_dn": MethodPropertyMeta("InDn", "inDn", "ReferenceObject", "Version142b", "Input", False),
    "in_user": MethodPropertyMeta("InUser", "inUser", "Xs:string", "Version142b", "Input", False),
    "out_allow": MethodPropertyMeta("OutAllow", "outAllow", "Xs:string", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inDn": "in_dn",
    "inUser": "in_user",
    "outAllow": "out_allow",
}



"""This module contains the general information for VnicOProfileAlias ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class VnicOProfileAliasConsts:
    MGMT_PLANE_RHEV_M = "rhev-m"
    MGMT_PLANE_SCVMM = "scvmm"
    MGMT_PLANE_UNMANAGED = "unmanaged"
    MGMT_PLANE_VCENTER = "vcenter"


class VnicOProfileAlias(ManagedObject):
    """This is VnicOProfileAlias class."""

    consts = VnicOProfileAliasConsts()
    naming_props = set(['vSwitchName', 'alias'])

    mo_meta = MoMeta("VnicOProfileAlias", "vnicOProfileAlias", "swid-[v_switch_name]alias-[alias]", VersionMeta.Version201m, "InputOutput", 0x7f, [], ["read-only"], ['vmVnicProfInst', 'vnicProfile'], [], ["Get"])

    prop_meta = {
        "alias": MoPropertyMeta("alias", "alias", "string", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x2, 1, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "mgmt_plane": MoPropertyMeta("mgmt_plane", "mgmtPlane", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["rhev-m", "scvmm", "unmanaged", "vcenter"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "v_switch_id": MoPropertyMeta("v_switch_id", "vSwitchId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{1,40}""", [], []),
        "v_switch_name": MoPropertyMeta("v_switch_name", "vSwitchName", "string", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x40, None, None, r"""[ !#$%&\(\)\*\+,\-\.:;=\?@\[\]_\{\|\}~a-zA-Z0-9]{1,16}""", [], []),
    }

    prop_map = {
        "alias": "alias", 
        "childAction": "child_action", 
        "dn": "dn", 
        "mgmtPlane": "mgmt_plane", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "vSwitchId": "v_switch_id", 
        "vSwitchName": "v_switch_name", 
    }

    def __init__(self, parent_mo_or_dn, v_switch_name, alias, **kwargs):
        self._dirty_mask = 0
        self.v_switch_name = v_switch_name
        self.alias = alias
        self.child_action = None
        self.mgmt_plane = None
        self.sacl = None
        self.status = None
        self.v_switch_id = None

        ManagedObject.__init__(self, "VnicOProfileAlias", parent_mo_or_dn, **kwargs)



"""This module contains the general information for EquipmentPOST ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentPOSTConsts:
    CREATED_NEVER = "never"
    GLOBAL_ID_NO_ERRORS = "No Errors"
    LOCAL_ID_NO_ERRORS = "No Errors"
    RECOVERABLE_NON_RECOVERABLE = "non-recoverable"
    RECOVERABLE_RECOVERABLE = "recoverable"
    RECOVERABLE_UNKNOWN = "unknown"
    SEVERITY_CLEARED = "cleared"
    SEVERITY_CONDITION = "condition"
    SEVERITY_CRITICAL = "critical"
    SEVERITY_INFO = "info"
    SEVERITY_MAJOR = "major"
    SEVERITY_MINOR = "minor"
    SEVERITY_WARNING = "warning"


class EquipmentPOST(ManagedObject):
    """This is EquipmentPOST class."""

    consts = EquipmentPOSTConsts()
    naming_props = set(['globalId'])

    mo_meta = MoMeta("EquipmentPOST", "equipmentPOST", "code-[global_id]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["read-only"], ['adaptorUnit', 'computeBlade', 'computeRackUnit', 'computeServerUnit', 'equipmentFex', 'equipmentIOCard'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "code": MoPropertyMeta("code", "code", "string", VersionMeta.Version111j, MoPropertyMeta.CREATE_ONLY, None, 0, 510, None, [], []),
        "created": MoPropertyMeta("created", "created", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,384}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "global_id": MoPropertyMeta("global_id", "globalId", "string", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, ["No Errors"], ["0-4294967295"]),
        "local_id": MoPropertyMeta("local_id", "localId", "string", VersionMeta.Version111j, MoPropertyMeta.CREATE_ONLY, None, None, None, None, ["No Errors"], ["0-4294967295"]),
        "method": MoPropertyMeta("method", "method", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""((POST|defaultValue|config-check|diag-check|sel-check),){0,4}(POST|defaultValue|config-check|diag-check|sel-check){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "recoverable": MoPropertyMeta("recoverable", "recoverable", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["non-recoverable", "recoverable", "unknown"], []),
        "recovery_action": MoPropertyMeta("recovery_action", "recoveryAction", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,384}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "severity": MoPropertyMeta("severity", "severity", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111j, MoPropertyMeta.CREATE_ONLY, None, 0, 510, None, [], []),
        "value": MoPropertyMeta("value", "value", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "code": "code", 
        "created": "created", 
        "descr": "descr", 
        "dn": "dn", 
        "globalId": "global_id", 
        "localId": "local_id", 
        "method": "method", 
        "name": "name", 
        "recoverable": "recoverable", 
        "recoveryAction": "recovery_action", 
        "rn": "rn", 
        "sacl": "sacl", 
        "severity": "severity", 
        "status": "status", 
        "type": "type", 
        "value": "value", 
    }

    def __init__(self, parent_mo_or_dn, global_id, **kwargs):
        self._dirty_mask = 0
        self.global_id = global_id
        self.child_action = None
        self.code = None
        self.created = None
        self.descr = None
        self.local_id = None
        self.method = None
        self.name = None
        self.recoverable = None
        self.recovery_action = None
        self.sacl = None
        self.severity = None
        self.status = None
        self.type = None
        self.value = None

        ManagedObject.__init__(self, "EquipmentPOST", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeFru ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeFruConsts:
    pass


class ApeFru(ManagedObject):
    """This is ApeFru class."""

    consts = ApeFruConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("ApeFru", "apeFru", "fru-[id]", VersionMeta.Version101e, "InputOutput", 0x7fffffff, [], ["read-only"], ['apeMcTable'], [], [None])

    prop_meta = {
        "board_fru": MoPropertyMeta("board_fru", "boardFru", "string", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x2, 0, 510, None, [], []),
        "board_manufacturer": MoPropertyMeta("board_manufacturer", "boardManufacturer", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, 0, 510, None, [], []),
        "board_mfg_time": MoPropertyMeta("board_mfg_time", "boardMfgTime", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []),
        "board_part_no": MoPropertyMeta("board_part_no", "boardPartNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, 0, 510, None, [], []),
        "board_product_name": MoPropertyMeta("board_product_name", "boardProductName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, 0, 510, None, [], []),
        "board_serial_no": MoPropertyMeta("board_serial_no", "boardSerialNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []),
        "board_vid": MoPropertyMeta("board_vid", "boardVid", "string", VersionMeta.Version203a, MoPropertyMeta.READ_WRITE, 0x80, 0, 510, None, [], []),
        "chassis_part_no": MoPropertyMeta("chassis_part_no", "chassisPartNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []),
        "chassis_serial_no": MoPropertyMeta("chassis_serial_no", "chassisSerialNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, 0, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x400, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "control_plane_mac1": MoPropertyMeta("control_plane_mac1", "controlPlaneMac1", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "control_plane_mac2": MoPropertyMeta("control_plane_mac2", "controlPlaneMac2", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "data_plane_mac1": MoPropertyMeta("data_plane_mac1", "dataPlaneMac1", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "data_plane_mac2": MoPropertyMeta("data_plane_mac2", "dataPlaneMac2", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4000, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "data_plane_wwn1": MoPropertyMeta("data_plane_wwn1", "dataPlaneWwn1", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8000, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []),
        "data_plane_wwn2": MoPropertyMeta("data_plane_wwn2", "dataPlaneWwn2", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10000, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20000, 0, 256, None, [], []),
        "entity_type": MoPropertyMeta("entity_type", "entityType", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40000, None, None, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80000, None, None, None, [], []),
        "instance": MoPropertyMeta("instance", "instance", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100000, None, None, None, [], []),
        "product_asset_tag": MoPropertyMeta("product_asset_tag", "productAssetTag", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200000, 0, 510, None, [], []),
        "product_fru": MoPropertyMeta("product_fru", "productFru", "string", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x400000, 0, 510, None, [], []),
        "product_manufacturer": MoPropertyMeta("product_manufacturer", "productManufacturer", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800000, 0, 510, None, [], []),
        "product_name": MoPropertyMeta("product_name", "productName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x1000000, 0, 510, None, [], []),
        "product_part_no": MoPropertyMeta("product_part_no", "productPartNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2000000, 0, 510, None, [], []),
        "product_serial_no": MoPropertyMeta("product_serial_no", "productSerialNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4000000, 0, 510, None, [], []),
        "product_version_no": MoPropertyMeta("product_version_no", "productVersionNo", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8000000, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10000000, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20000000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40000000, None, None, None, [], []),
    }

    prop_map = {
        "boardFru": "board_fru", 
        "boardManufacturer": "board_manufacturer", 
        "boardMfgTime": "board_mfg_time", 
        "boardPartNo": "board_part_no", 
        "boardProductName": "board_product_name", 
        "boardSerialNo": "board_serial_no", 
        "boardVid": "board_vid", 
        "chassisPartNo": "chassis_part_no", 
        "chassisSerialNo": "chassis_serial_no", 
        "childAction": "child_action", 
        "controlPlaneMac1": "control_plane_mac1", 
        "controlPlaneMac2": "control_plane_mac2", 
        "dataPlaneMac1": "data_plane_mac1", 
        "dataPlaneMac2": "data_plane_mac2", 
        "dataPlaneWwn1": "data_plane_wwn1", 
        "dataPlaneWwn2": "data_plane_wwn2", 
        "dn": "dn", 
        "entityType": "entity_type", 
        "id": "id", 
        "instance": "instance", 
        "productAssetTag": "product_asset_tag", 
        "productFru": "product_fru", 
        "productManufacturer": "product_manufacturer", 
        "productName": "product_name", 
        "productPartNo": "product_part_no", 
        "productSerialNo": "product_serial_no", 
        "productVersionNo": "product_version_no", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.board_fru = None
        self.board_manufacturer = None
        self.board_mfg_time = None
        self.board_part_no = None
        self.board_product_name = None
        self.board_serial_no = None
        self.board_vid = None
        self.chassis_part_no = None
        self.chassis_serial_no = None
        self.child_action = None
        self.control_plane_mac1 = None
        self.control_plane_mac2 = None
        self.data_plane_mac1 = None
        self.data_plane_mac2 = None
        self.data_plane_wwn1 = None
        self.data_plane_wwn2 = None
        self.entity_type = None
        self.instance = None
        self.product_asset_tag = None
        self.product_fru = None
        self.product_manufacturer = None
        self.product_name = None
        self.product_part_no = None
        self.product_serial_no = None
        self.product_version_no = None
        self.sacl = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "ApeFru", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricDceSwSrvPc ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricDceSwSrvPcConsts:
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    CHASSIS_ID_N_A = "N/A"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    OPER_SPEED_100GBPS = "100gbps"
    OPER_SPEED_10GBPS = "10gbps"
    OPER_SPEED_1GBPS = "1gbps"
    OPER_SPEED_20GBPS = "20gbps"
    OPER_SPEED_25GBPS = "25gbps"
    OPER_SPEED_40GBPS = "40gbps"
    OPER_SPEED_AUTO = "auto"
    OPER_SPEED_INDETERMINATE = "indeterminate"
    OPER_STATE_ADMIN_DOWN = "admin-down"
    OPER_STATE_DOWN = "down"
    OPER_STATE_ERROR_DISABLED = "error-disabled"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_HARDWARE_FAILURE = "hardware-failure"
    OPER_STATE_INDETERMINATE = "indeterminate"
    OPER_STATE_LINK_DOWN = "link-down"
    OPER_STATE_LINK_UP = "link-up"
    OPER_STATE_NO_LICENSE = "no-license"
    OPER_STATE_SFP_NOT_PRESENT = "sfp-not-present"
    OPER_STATE_SOFTWARE_FAILURE = "software-failure"
    OPER_STATE_UDLD_AGGR_DOWN = "udld-aggr-down"
    OPER_STATE_UP = "up"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"


class FabricDceSwSrvPc(ManagedObject):
    """This is FabricDceSwSrvPc class."""

    consts = FabricDceSwSrvPcConsts()
    naming_props = set(['portId'])

    mo_meta = MoMeta("FabricDceSwSrvPc", "fabricDceSwSrvPc", "pc-[port_id]", VersionMeta.Version201m, "InputOutput", 0xff, [], ["admin", "ls-network", "ls-network-policy"], ['fabricDceSwSrv'], ['fabricDceSwSrvPcEp', 'fabricSubGroup', 'faultInst'], ["Get"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_speed": MoPropertyMeta("oper_speed", "operSpeed", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["100gbps", "10gbps", "1gbps", "20gbps", "25gbps", "40gbps", "auto", "indeterminate"], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["admin-down", "down", "error-disabled", "failed", "hardware-failure", "indeterminate", "link-down", "link-up", "no-license", "sfp-not-present", "software-failure", "udld-aggr-down", "up"], []),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "port_id": MoPropertyMeta("port_id", "portId", "uint", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x20, None, None, None, [], ["1024-4096"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "state_qual": MoPropertyMeta("state_qual", "stateQual", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "fltAggr": "flt_aggr", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "locale": "locale", 
        "name": "name", 
        "operSpeed": "oper_speed", 
        "operState": "oper_state", 
        "peerDn": "peer_dn", 
        "portId": "port_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stateQual": "state_qual", 
        "status": "status", 
        "switchId": "switch_id", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, port_id, **kwargs):
        self._dirty_mask = 0
        self.port_id = port_id
        self.admin_state = None
        self.chassis_id = None
        self.child_action = None
        self.descr = None
        self.ep_dn = None
        self.flt_aggr = None
        self.if_role = None
        self.if_type = None
        self.locale = None
        self.name = None
        self.oper_speed = None
        self.oper_state = None
        self.peer_dn = None
        self.sacl = None
        self.state_qual = None
        self.status = None
        self.switch_id = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricDceSwSrvPc", parent_mo_or_dn, **kwargs)



"""This module contains the general information for DhcpAcquired ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class DhcpAcquiredConsts:
    pass


class DhcpAcquired(ManagedObject):
    """This is DhcpAcquired class."""

    consts = DhcpAcquiredConsts()
    naming_props = set([])

    mo_meta = MoMeta("DhcpAcquired", "dhcpAcquired", "lease", VersionMeta.Version141i, "InputOutput", 0x1f, [], ["read-only"], ['adaptorHostEthIf', 'mgmtIf'], [], ["Get"])

    prop_meta = {
        "acqts": MoPropertyMeta("acqts", "acqts", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cookie": MoPropertyMeta("cookie", "cookie", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ends": MoPropertyMeta("ends", "ends", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "ip": MoPropertyMeta("ip", "ip", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "mac": MoPropertyMeta("mac", "mac", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "sys_id": MoPropertyMeta("sys_id", "sysId", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "acqts": "acqts", 
        "childAction": "child_action", 
        "cookie": "cookie", 
        "dn": "dn", 
        "ends": "ends", 
        "ip": "ip", 
        "mac": "mac", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "sysId": "sys_id", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.acqts = None
        self.child_action = None
        self.cookie = None
        self.ends = None
        self.ip = None
        self.mac = None
        self.sacl = None
        self.status = None
        self.sys_id = None

        ManagedObject.__init__(self, "DhcpAcquired", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of StatsClearInterval ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("StatsClearInterval", "statsClearInterval", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_dns": MethodPropertyMeta("InDns", "inDns", "DnSet", "Version142b", "Input", True),
}

prop_map = {
    "cookie": "cookie",
    "inDns": "in_dns",
}



"""This module contains the general information for FirmwareInfraPack ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareInfraPackConsts:
    EVACUATE_FALSE = "false"
    EVACUATE_NO = "no"
    EVACUATE_TRUE = "true"
    EVACUATE_YES = "yes"
    FORCE_DEPLOY_FALSE = "false"
    FORCE_DEPLOY_NO = "no"
    FORCE_DEPLOY_TRUE = "true"
    FORCE_DEPLOY_YES = "yes"
    INT_ID_NONE = "none"
    MODE_ONE_SHOT = "one-shot"
    MODE_STAGED = "staged"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    SKIP_VALIDATION_FALSE = "false"
    SKIP_VALIDATION_NO = "no"
    SKIP_VALIDATION_TRUE = "true"
    SKIP_VALIDATION_YES = "yes"
    UPDATE_TRIGGER_IMMEDIATE = "immediate"


class FirmwareInfraPack(ManagedObject):
    """This is FirmwareInfraPack class."""

    consts = FirmwareInfraPackConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FirmwareInfraPack", "firmwareInfraPack", "fw-infra-pack-[name]", VersionMeta.Version211a, "InputOutput", 0x7fff, [], ["admin"], ['orgOrg'], ['firmwareBackupVersionHolder', 'firmwarePackItem'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "evacuate": MoPropertyMeta("evacuate", "evacuate", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["false", "no", "true", "yes"], []),
        "force_deploy": MoPropertyMeta("force_deploy", "forceDeploy", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []),
        "infra_bundle_name": MoPropertyMeta("infra_bundle_name", "infraBundleName", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "infra_bundle_version": MoPropertyMeta("infra_bundle_version", "infraBundleVersion", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["one-shot", "staged"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "service_pack_bundle_name": MoPropertyMeta("service_pack_bundle_name", "servicePackBundleName", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "service_pack_bundle_version": MoPropertyMeta("service_pack_bundle_version", "servicePackBundleVersion", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x800, 0, 510, None, [], []),
        "skip_validation": MoPropertyMeta("skip_validation", "skipValidation", "string", VersionMeta.Version226c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "stage_size": MoPropertyMeta("stage_size", "stageSize", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "update_trigger": MoPropertyMeta("update_trigger", "updateTrigger", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x4000, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["immediate"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "evacuate": "evacuate", 
        "forceDeploy": "force_deploy", 
        "infraBundleName": "infra_bundle_name", 
        "infraBundleVersion": "infra_bundle_version", 
        "intId": "int_id", 
        "mode": "mode", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "servicePackBundleName": "service_pack_bundle_name", 
        "servicePackBundleVersion": "service_pack_bundle_version", 
        "skipValidation": "skip_validation", 
        "stageSize": "stage_size", 
        "status": "status", 
        "updateTrigger": "update_trigger", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.evacuate = None
        self.force_deploy = None
        self.infra_bundle_name = None
        self.infra_bundle_version = None
        self.int_id = None
        self.mode = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.service_pack_bundle_name = None
        self.service_pack_bundle_version = None
        self.skip_validation = None
        self.stage_size = None
        self.status = None
        self.update_trigger = None

        ManagedObject.__init__(self, "FirmwareInfraPack", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of MgmtResolveBackupFilenames ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("MgmtResolveBackupFilenames", "mgmtResolveBackupFilenames", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_backup_source": MethodPropertyMeta("InBackupSource", "inBackupSource", "Xs:string", "Version142b", "Input", False),
    "in_type": MethodPropertyMeta("InType", "inType", "Xs:string", "Version142b", "Input", False),
    "out_backups": MethodPropertyMeta("OutBackups", "outBackups", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inBackupSource": "in_backup_source",
    "inType": "in_type",
    "outBackups": "out_backups",
}



"""This module contains the meta information of ConfigGetXmlFileStr ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigGetXmlFileStr", "configGetXmlFileStr", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_file_path": MethodPropertyMeta("InFilePath", "inFilePath", "Xs:string", "Version142b", "Input", False),
    "out_config": MethodPropertyMeta("OutConfig", "outConfig", "Xs:string", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inFilePath": "in_file_path",
    "outConfig": "out_config",
}



"""This module contains the meta information of EventRegisterEventChannel ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("EventRegisterEventChannel", "eventRegisterEventChannel", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_dn": MethodPropertyMeta("InDn", "inDn", "Xs:string", "Version142b", "Input", False),
    "out_req_id": MethodPropertyMeta("OutReqID", "outReqID", "Xs:unsignedInt", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inDn": "in_dn",
    "outReqID": "out_req_id",
}



"""This module contains the general information for CallhomeAnonymousReporting ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class CallhomeAnonymousReportingConsts:
    ADMIN_STATE_OFF = "off"
    ADMIN_STATE_ON = "on"
    USER_ACKNOWLEDGED_FALSE = "false"
    USER_ACKNOWLEDGED_NO = "no"
    USER_ACKNOWLEDGED_TRUE = "true"
    USER_ACKNOWLEDGED_YES = "yes"


class CallhomeAnonymousReporting(ManagedObject):
    """This is CallhomeAnonymousReporting class."""

    consts = CallhomeAnonymousReportingConsts()
    naming_props = set([])

    mo_meta = MoMeta("CallhomeAnonymousReporting", "callhomeAnonymousReporting", "anonymousreporting", VersionMeta.Version223a, "InputOutput", 0x7f, [], ["admin"], ['callhomeEp'], [], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["off", "on"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version223a, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "count": MoPropertyMeta("count", "count", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "sleep_interval": MoPropertyMeta("sleep_interval", "sleepInterval", "uint", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "user_acknowledged": MoPropertyMeta("user_acknowledged", "userAcknowledged", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "count": "count", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sleepInterval": "sleep_interval", 
        "status": "status", 
        "userAcknowledged": "user_acknowledged", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_state = None
        self.child_action = None
        self.count = None
        self.sacl = None
        self.sleep_interval = None
        self.status = None
        self.user_acknowledged = None

        ManagedObject.__init__(self, "CallhomeAnonymousReporting", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeMcGetParam ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeMcGetParam", "apeMcGetParam", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_mc_ip": MethodPropertyMeta("InMcIp", "inMcIp", "AddressIPv4", "Version142b", "Input", False),
    "in_param_ids": MethodPropertyMeta("InParamIds", "inParamIds", "IdSet", "Version142b", "Input", True),
    "out_param_vals": MethodPropertyMeta("OutParamVals", "outParamVals", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inMcIp": "in_mc_ip",
    "inParamIds": "in_param_ids",
    "outParamVals": "out_param_vals",
}



"""This module contains the meta information of ApeGetIpFromSerial ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeGetIpFromSerial", "apeGetIpFromSerial", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_equipment_serial": MethodPropertyMeta("InEquipmentSerial", "inEquipmentSerial", "Xs:string", "Version142b", "Input", False),
    "out_ip_addr": MethodPropertyMeta("OutIpAddr", "outIpAddr", "AddressIPv4", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inEquipmentSerial": "in_equipment_serial",
    "outIpAddr": "out_ip_addr",
}



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from six.moves import configparser

host = "ucs"
skip_msg = "Not connected to a valid UCSM domain."


def custom_setup():
    import os
    from ucsmsdk.ucshandle import UcsHandle

    config = configparser.RawConfigParser()
    config.read(os.path.join(os.path.dirname(__file__), '..', 'connection',
                             'connection.cfg'))
    try:
        hostname = config.get(host, "hostname")
        username = config.get(host, "username")
        password = config.get(host, "password")
    except:
        return None
    handle = UcsHandle(hostname, username, password)
    handle.login(auto_refresh=True, force=True)
    return handle


def custom_teardown(handle):
    if handle:
        handle.logout()


def get_skip_msg():
    return skip_msg
